@@ -34,11 +34,11 @@
 #include "private/xdgbasedirs_p.h"
 #include "private/externalpartstorage_p.h"
 
-#include <QtCore/QDateTime>
-#include <QtCore/QFile>
-#include <QtCore/QVarLengthArray>
-#include <QtCore/QFileInfo>
-#include <QtCore/QDir>
+#include <QDateTime>
+#include <QFile>
+#include <QVarLengthArray>
+#include <QFileInfo>
+#include <QDir>
 
 #include <KLocalizedString>
 
