@@ -20,10 +20,9 @@
 #ifndef AKONADISERVER_H
 #define AKONADISERVER_H
 
-#include <QtCore/QPointer>
-#include <QtCore/QVector>
-
-#include <QtNetwork/QLocalServer>
+#include <QObject>
+#include <QPointer>
+#include <QVector>
 
 class QProcess;
 
@@ -38,8 +37,10 @@ class SearchManager;
 class StorageJanitor;
 class CacheCleaner;
 class IntervalCheck;
+class AkLocalServer;
+class NotificationManager;
 
-class AkonadiServer : public QLocalServer
+class AkonadiServer : public QObject
 {
     Q_OBJECT
 
@@ -57,6 +58,13 @@ public:
      */
     IntervalCheck *intervalChecker();
 
+    QString serverPath() const;
+
+    /**
+     * Can return a nullptr
+     */
+    NotificationManager *notificationManager();
+
 public Q_SLOTS:
     /**
      * Triggers a clean server shutdown.
@@ -65,30 +73,35 @@ public Q_SLOTS:
 
     virtual bool init();
 
+protected Q_SLOTS:
+    virtual void newCmdConnection(quintptr socketDescriptor);
+
 private Q_SLOTS:
     void doQuit();
     void serviceOwnerChanged(const QString &name, const QString &oldOwner, const QString &newOwner);
     void connectionDisconnected();
 
-protected:
-    /** reimpl */
-    void incomingConnection(quintptr socketDescriptor) Q_DECL_OVERRIDE;
-
 private:
     bool startDatabaseProcess();
     bool createDatabase();
     void stopDatabaseProcess();
+    uint userId() const;
+
 
 protected:
     AkonadiServer(QObject *parent = Q_NULLPTR);
 
+    AkLocalServer *mCmdServer;
+    AkLocalServer *mNtfServer;
+
+    NotificationManager *mNotificationManager;
     CacheCleaner *mCacheCleaner;
     IntervalCheck *mIntervalCheck;
     StorageJanitor *mStorageJanitor;
     ItemRetrievalManager *mItemRetrieval;
     SearchTaskManager *mAgentSearchManager;
     QProcess *mDatabaseProcess;
-    QVector<QPointer<Connection>> mConnections;
+    QVector<Connection *> mConnections;
     SearchManager *mSearchManager;
     bool mAlreadyShutdown;
 
