@@ -127,8 +127,8 @@ void CacheCleaner::collectionExpired(const Collection &collection)
     qb.addValueCondition(PimItem::dirtyFullColumnName(), Query::Equals, false);
 
     QStringList localParts;
-    QStringList partNames = collection.cachePolicyLocalParts().split(QStringLiteral(" "));
-    Q_FOREACH (QString partName, partNames) {
+    const QStringList partNames = collection.cachePolicyLocalParts().split(QStringLiteral(" "));
+    Q_FOREACH (QString partName, partNames) {   // krazy:exclude=foreach
         if (partName.startsWith(QLatin1String(AKONADI_PARAM_PLD))) {
             partName = partName.mid(4);
         }
@@ -139,7 +139,7 @@ void CacheCleaner::collectionExpired(const Collection &collection)
         if (!parts.isEmpty()) {
             qCDebug(AKONADISERVER_LOG) << "found" << parts.count() << "item parts to expire in collection" << collection.name();
             // clear data field
-            Q_FOREACH (Part part, parts) {
+            Q_FOREACH (Part part, parts) {  // krazy:exclude=foreach
                 try {
                     if (!PartHelper::truncate(part)) {
                         qCDebug(AKONADISERVER_LOG) << "failed to update item part" << part.id();
