@@ -113,29 +113,24 @@ Handler *Handler::findHandlerForCommandAuthenticated(Protocol::Command::Type cmd
     switch (cmd)
     {
     case Protocol::Command::Invalid:
-        Q_ASSERT_X(cmd != Protocol::Command::Invalid,
-                   "Handler::findHandlerForCommandAuthenticated()",
+        Q_ASSERT_X(cmd != Protocol::Command::Invalid, __FUNCTION__,
                    "Invalid command is not allowed");
         return Q_NULLPTR;
     case Protocol::Command::Hello:
-        Q_ASSERT_X(cmd != Protocol::Command::Hello,
-                    "Handler::findHandlerForCommandAuthenticated()",
-                    "Hello command is not allowed in this context");
+        Q_ASSERT_X(cmd != Protocol::Command::Hello, __FUNCTION__,
+                   "Hello command is not allowed in this context");
         return Q_NULLPTR;
     case Protocol::Command::Login:
-        Q_ASSERT_X(cmd != Protocol::Command::StreamPayload,
-                    "Handler::findHandlerForCommandAuthenticated()",
-                    "Login command is not allowed in this context");
+        Q_ASSERT_X(cmd != Protocol::Command::StreamPayload, __FUNCTION__,
+                   "Login command is not allowed in this context");
         return Q_NULLPTR;
     case Protocol::Command::Logout:
-        Q_ASSERT_X(cmd != Protocol::Command::StreamPayload,
-            "Handler::findHandlerForCommandAuthenticated()",
-            "Logout command is not allowed in this context");
+        Q_ASSERT_X(cmd != Protocol::Command::StreamPayload, __FUNCTION__,
+                   "Logout command is not allowed in this context");
         return Q_NULLPTR;
     case Protocol::Command::_ResponseBit:
-        Q_ASSERT_X(cmd != Protocol::Command::_ResponseBit,
-            "Handler::findHandlerForCommandAuthenticated()",
-            "ResponseBit is not a valid command type");
+        Q_ASSERT_X(cmd != Protocol::Command::_ResponseBit, __FUNCTION__,
+                   "ResponseBit is not a valid command type");
         return Q_NULLPTR;
 
     case Protocol::Command::Transaction:
@@ -198,14 +193,40 @@ Handler *Handler::findHandlerForCommandAuthenticated(Protocol::Command::Type cmd
         return new ResourceSelect();
 
     case Protocol::Command::StreamPayload:
-        Q_ASSERT_X(cmd != Protocol::Command::StreamPayload,
-                    "Handler::findHandlerForCommandAuthenticated()",
-                    "StreamPayload command is not allowed in this context");
+        Q_ASSERT_X(cmd != Protocol::Command::StreamPayload, __FUNCTION__,
+                   "StreamPayload command is not allowed in this context");
+        return Q_NULLPTR;
+
+    case Protocol::Command::ItemChangeNotification:
+        Q_ASSERT_X(cmd != Protocol::Command::ItemChangeNotification, __FUNCTION__,
+                   "ItemChangeNotification command is not allowed on this connection");
+        return Q_NULLPTR;
+    case Protocol::Command::CollectionChangeNotification:
+        Q_ASSERT_X(cmd != Protocol::Command::CollectionChangeNotification, __FUNCTION__,
+                   "CollectionChangeNotification command is not allowed on this connection");
+        return Q_NULLPTR;
+    case Protocol::Command::TagChangeNotification:
+        Q_ASSERT_X(cmd != Protocol::Command::TagChangeNotification, __FUNCTION__,
+                   "TagChangeNotification command is not allowed on this connection");
+        return Q_NULLPTR;
+    case Protocol::Command::RelationChangeNotification:
+        Q_ASSERT_X(cmd != Protocol::Command::RelationChangeNotification, __FUNCTION__,
+                   "RelationChangeNotification command is not allowed on this connection");
+        return Q_NULLPTR;
+    case Protocol::Command::SubscriptionChangeNotification:
+        Q_ASSERT_X(cmd != Protocol::Command::SubscriptionChangeNotification, __FUNCTION__,
+                   "SubscriptionChangeNotification command is not allowed on this connection");
+    case Protocol::Command::DebugChangeNotification:
+        Q_ASSERT_X(cmd != Protocol::Command::DebugChangeNotification, __FUNCTION__,
+                   "DebugChangeNotification command is not allowed on this connection");
+    case Protocol::Command::ModifySubscription:
+        Q_ASSERT_X(cmd != Protocol::Command::ModifySubscription, __FUNCTION__,
+                   "ModifySubscription command is not allowed on this connection");
+        return Q_NULLPTR;
+    case Protocol::Command::CreateSubscription:
+        Q_ASSERT_X(cmd != Protocol::Command::CreateSubscription, __FUNCTION__,
+                   "CreateSubscription command is not allowed on this connection");
         return Q_NULLPTR;
-    case Protocol::Command::ChangeNotification:
-        Q_ASSERT_X(cmd != Protocol::Command::ChangeNotification,
-                   "Handler::findHandlerForCommandNonAuthenticated()",
-                   "ChangeNotification command is not allowed in this context");
     }
 
     return Q_NULLPTR;
