@@ -20,13 +20,13 @@
 #ifndef DATASTORE_H
 #define DATASTORE_H
 
-#include <QtCore/QObject>
-#include <QtCore/QList>
-#include <QtCore/QMutex>
-#include <QtCore/QVector>
-#include <QtCore/QWaitCondition>
-#include <QtCore/QThreadStorage>
-#include <QtSql/QSqlDatabase>
+#include <QObject>
+#include <QList>
+#include <QMutex>
+#include <QVector>
+#include <QWaitCondition>
+#include <QThreadStorage>
+#include <QSqlDatabase>
 
 class QSqlQuery;
 class QTimer;
@@ -176,11 +176,9 @@ public:
 
     QMap< Server::Entity::Id, QList< PimItem > > virtualCollections(const Akonadi::Server::PimItem::List &items);
 
-    /* --- MimeType ------------------------------------------------------ */
-    virtual bool appendMimeType(const QString &mimetype, qint64 *insertId = 0);
-
     /* --- PimItem ------------------------------------------------------- */
     virtual bool appendPimItem(QVector<Part> &parts,
+                               const QVector<Flag> &flags,
                                const MimeType &mimetype,
                                const Collection &collection,
                                const QDateTime &dateTime,
